/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
import java.io.File;
import java.util.HashMap;
import java.util.Map;

import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperPrintManager;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.engine.util.AbstractSampleApp;
import net.sf.jasperreports.engine.util.JRLoader;
import net.sf.jasperreports.export.SimpleExporterInput;
import net.sf.jasperreports.export.SimpleOutputStreamExporterOutput;

import com.aspose.cells.jasperreports.ACXlsExporter;
import com.aspose.cells.jasperreports.ACXlsReportConfiguration;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class SubreportApp extends AbstractSampleApp
{


    /**
     *
     */
    public static void main(String[] args) 
    {
        main(new SubreportApp(), args);
    }
    
    
    /**
     *
     */
    public void test() throws JRException
    {
        fill();
        cellsReport("EXCEL2007", ".xlsx");
        cellsReport("EXCEL97TO2003", ".xls");
    }
    
    
    /**
     *
     */
    public void fill() throws JRException
    {
        long start = System.currentTimeMillis();
        JasperReport subreport = (JasperReport)JRLoader.loadObjectFromFile("build/reports/ProductReport.jasper");

        //Preparing parameters
        Map<String, Object> parameters = new HashMap<String, Object>();
        parameters.put("ProductsSubreport", subreport);
        
        JasperFillManager.fillReportToFile("build/reports/MasterReport.jasper", parameters, getDemoHsqldbConnection());
        System.err.println("Filling time : " + (System.currentTimeMillis() - start));
    }
    
    
    /**
     *
     */
    public void print() throws JRException
    {
        long start = System.currentTimeMillis();
        JasperPrintManager.printReport("build/reports/MasterReport.jrprint", true);
        System.err.println("Printing time : " + (System.currentTimeMillis() - start));
    }
    
    private void cellsReport(String formatType, String ext) throws JRException
    {
        long start = System.currentTimeMillis();
        File sourceFile = new File("build/reports/MasterReport.jrprint");

        JasperPrint jasperPrint = (JasperPrint)JRLoader.loadObject(sourceFile);

        File destFile = new File(sourceFile.getParent(), jasperPrint.getName() + ".ac." + ext);
        
        ACXlsExporter exporter = new ACXlsExporter();
        ACXlsReportConfiguration conf = new ACXlsReportConfiguration();
        conf.setFormatType(formatType);
        conf.setOnePagePerSheet(true);
        exporter.setConfiguration(conf);
        exporter.setExporterInput(new SimpleExporterInput(jasperPrint));
        exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(destFile));

        exporter.exportReport();

        System.err.println(ext + " creation time : " + (System.currentTimeMillis() - start));
    }
}
