/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
import java.io.File;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRParameter;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperPrintManager;
import net.sf.jasperreports.engine.query.JRXPathQueryExecuterFactory;
import net.sf.jasperreports.engine.util.AbstractSampleApp;
import net.sf.jasperreports.engine.util.JRLoader;
import net.sf.jasperreports.engine.util.JRXmlUtils;
import net.sf.jasperreports.export.SimpleExporterInput;
import net.sf.jasperreports.export.SimpleOutputStreamExporterOutput;

import org.w3c.dom.Document;

import com.aspose.cells.jasperreports.ACXlsExporter;
import com.aspose.cells.jasperreports.ACXlsReportConfiguration;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class XmlDataSourceApp extends AbstractSampleApp
{
    

    /**
     *
     */
    public static void main(String[] args)
    {
        main(new XmlDataSourceApp(), args);
    }
    
    
    /**
     *
     */
    public void test() throws JRException
    {
        fill();
        cellsReport("EXCEL2007", ".xlsx");
        cellsReport("EXCEL97TO2003", ".xls");
    }


    /**
     *
     */
    public void fill() throws JRException
    {
        long start = System.currentTimeMillis();
        Map<String, Object> params = new HashMap<String, Object>();
        Document document = JRXmlUtils.parse(JRLoader.getLocationInputStream("data/northwind.xml"));
        params.put(JRXPathQueryExecuterFactory.PARAMETER_XML_DATA_DOCUMENT, document);
        params.put(JRXPathQueryExecuterFactory.XML_DATE_PATTERN, "yyyy-MM-dd");
        params.put(JRXPathQueryExecuterFactory.XML_NUMBER_PATTERN, "#,##0.##");
        params.put(JRXPathQueryExecuterFactory.XML_LOCALE, Locale.ENGLISH);
        params.put(JRParameter.REPORT_LOCALE, Locale.US);
        
        JasperFillManager.fillReportToFile("build/reports/CustomersReport.jasper", params);
        System.err.println("Filling time : " + (System.currentTimeMillis() - start));
    }


    /**
     *
     */
    public void print() throws JRException
    {
        long start = System.currentTimeMillis();
        JasperPrintManager.printReport("build/reports/CustomersReport.jrprint", true);
        System.err.println("Printing time : " + (System.currentTimeMillis() - start));
    }

    private void cellsReport(String formatType, String ext) throws JRException
    {
        long start = System.currentTimeMillis();
        File sourceFile = new File("build/reports/CustomersReport.jrprint");

        JasperPrint jasperPrint = (JasperPrint)JRLoader.loadObject(sourceFile);

        File destFile = new File(sourceFile.getParent(), jasperPrint.getName() + ".ac." + ext);
        
        ACXlsExporter exporter = new ACXlsExporter();
        ACXlsReportConfiguration conf = new ACXlsReportConfiguration();
        conf.setFormatType(formatType);
        conf.setOnePagePerSheet(true);
        exporter.setConfiguration(conf);
        exporter.setExporterInput(new SimpleExporterInput(jasperPrint));
        exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(destFile));

        exporter.exportReport();

        System.err.println(ext + " creation time : " + (System.currentTimeMillis() - start));
    }
}
